@@ -8,6 +8,8 @@ from typing import (
     Optional,
     Iterable,
     get_args,
+    Dict,
+    Any,
 )
 from abc import abstractmethod
 import logging
@@ -65,7 +67,7 @@ class Request(AbstractRequest[T]):
     @request_method.setter
     def request_method(self, value: HttpsMethod) -> None:
         self._method = value
-        Logger.info("%s.Method: _method set to %s", type(self).__name__, value)
+        Logger.info("%s.Method: request method set to %s", type(self).__name__, value)
 
     @property
     def request_url(self: B) -> str:
@@ -80,6 +82,7 @@ class Request(AbstractRequest[T]):
     @request_url.setter
     def request_url(self: B, value: str) -> None:
         self._request_url = value
+        Logger.info("%s.request_url: request URL set to %s", type(self).__name__, value)
 
     @property
     @final
@@ -123,14 +126,14 @@ class Request(AbstractRequest[T]):
 
         return url._replace(query="").geturl()
 
-    def Send(self, __object: Optional[T]) -> Optional[Union[List[T], T]]:
+    def Send(self, __object: Optional[Union[T, Dict[str, Any]]]) -> Optional[Union[List[T], T]]:
         """Submits the request and returns the expected return"""
 
         Logger.info("%s.Send: method called", type(self).__name__)
 
         return self.send_request(__object)
 
-    def send_request(self, value: Optional[T]) -> Optional[Union[List[T], T]]:
+    def send_request(self, value: Optional[Union[T, Dict[str, Any]]]) -> Optional[Union[List[T], T]]:
         """Makes the desired request and returns the desired return type"""
 
         Logger.info("%s.SendRequest: method called", type(self).__name__)
