@@ -8,6 +8,7 @@ from typing import (
     final,
     get_args,
 )
+from abc import abstractmethod
 from pyrestsdk import AbstractServiceClient
 from pyrestsdk.type.model import (
     QueryOption,
@@ -34,29 +35,12 @@ class AbstractRequestBuilder(Generic[T]):
         self._client = client
 
     @property
+    @abstractmethod
     def Client(self: B) -> S:
         """Gets the Client"""
 
-        return self._client
-
-    @property
-    @final
-    def generic_type(self: B) -> Type[T]:
-        """Gets the the type argument provided"""
-
-        # used if type arg is provided in constructor
-        orig_value = getattr(self, "__orig_class__", None)
-
-        if orig_value is None:
-            # used if typ arg is provided when subclassing
-            orig_bases = getattr(self, "__orig_bases__")
-            orig_value = orig_bases[0]
-
-        _type: Type[T] = get_args(orig_value)[0]
-
-        return _type
-
     @property
+    @abstractmethod
     def request_url(self: B) -> str:
         """Gets/Sets the request URL
 
@@ -64,12 +48,7 @@ class AbstractRequestBuilder(Generic[T]):
             str: The request URL
         """
 
-        return self._request_url
-
-    @request_url.setter
-    def request_url(self: B, value: str) -> None:
-        self._request_url = value
-
+    @abstractmethod
     def append_segment_to_request_url(self, url_segment: str) -> str:
         """Gets a URL that is the request builder's request URL with the segment appended.
 
@@ -79,8 +58,3 @@ class AbstractRequestBuilder(Generic[T]):
         Returns:
             str: A URL that is the request builder's request URL with the segment appended.
         """
-
-        if not url_segment.startswith("/"):
-            url_segment = f"/{url_segment}"
-
-        return f"{self.request_url}{url_segment}"
