@@ -1,3 +1,5 @@
+"""Houses Models"""
+
 from pyrestsdk.type.model._base_entity import BaseEntity
 from pyrestsdk.type.model._option import Option
 from pyrestsdk.type.model._query_option import QueryOption
@@ -5,5 +7,15 @@ from pyrestsdk.type.model._header_option import HeaderOption
 from pyrestsdk.type.model._options_collection import OptionsCollection
 from pyrestsdk.type.model._header_option_collection import HeaderOptionCollection
 from pyrestsdk.type.model._query_option_collection import QueryOptionCollection
+from pyrestsdk.type.model._type_collection import TypeCollection
 
-__all__ = ["BaseEntity", "Option", "QueryOption", "HeaderOption", "OptionsCollection", "HeaderOptionCollection", "QueryOptionCollection"]
\ No newline at end of file
+__all__ = [
+    "BaseEntity",
+    "Option",
+    "QueryOption",
+    "HeaderOption",
+    "OptionsCollection",
+    "HeaderOptionCollection",
+    "QueryOptionCollection",
+    "TypeCollection",
+]
