@@ -21,11 +21,6 @@ class BaseEntity:
     def __init__(self: S, client: A) -> None:
         self.__client = client
 
-    @property
-    @abstractmethod
-    def Json(self: S) -> Dict:
-        """Gets the object as it's dict representation"""
-
     @property
     @abstractmethod
     def as_dict(self) -> Dict:
@@ -33,7 +28,7 @@ class BaseEntity:
 
     @property
     @abstractmethod
-    def __json__(self) -> str:
+    def as_json(self) -> str:
         """Gest the object's json representation"""
 
     @property
